@@ -1,12 +1,12 @@
 /* cktsim.js
  *
- * Copyright (C) 2011 Massachusetts Institute of Technology
+ * SPDX-FileCopyrightText: 2011 Massachusetts Institute of Technology
+ * SPDX-License-Identifier: AGPL-3.0-only
  *
  * Authors:
  *   Massachusetts Institute of Technology (original engine)
  *   Aiswarya Kaitheri Kandoth <aiswaryakk29@gmail.com> (minimal edits to integrate in GCompris)
  *
- *  cktsim code is under AGPL-3.0 License
  *  Copied from https://github.com/edx/edx-platform/blob/master/common/lib/xmodule/xmodule/js/src/capa/schematic.js
  */
 
@@ -67,7 +67,7 @@ var cktsim = (function() {
 	}
 	
     // alert managed in GCompris
-    // (note: all alert function calls have been changed to this.alert...)
+    // (note: all alert function calls have been changed to this.alert... + added qsTr() for translation)
 	Circuit.prototype.alert = function(message_) {
         if(this.GCWarning === "") {
             this.GCWarning = message_;
@@ -135,8 +135,8 @@ var cktsim = (function() {
 		    }
 		    var rGV = mat_rank(GV);
 		    if (rGV < n_vsrc) {
-			this.alert('Warning!!! Circuit has a voltage source loop or a source shorted by a wire, please remove the source or the wire causing the short.');
-			this.alert('Warning!!! Simulator might produce meaningless results or no result with this circuit.');
+			this.alert(qsTr('Warning! Circuit has a voltage source loop or a source shorted by a wire, please remove the wire causing the short.'));
+			this.alert(qsTr('Warning! Simulator might produce meaningless results or no result with this circuit.'));
 			return false;
 		    }
 		}
