@@ -17,7 +17,7 @@
 */
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import Box2D 2.0 as Box2D
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import QtQml 2.12 as Qml
@@ -78,11 +78,12 @@ function start(items_) {
         if (GCompris.ApplicationInfo.isMobile) {
             // we don't have many touch events, therefore disable screensaver on android:
             GCompris.ApplicationInfo.setKeepScreenOn(true);
-            // lock screen orientation to landscape:
-            GCompris.ApplicationInfo.setRequestedOrientation(0);
-            if (GCompris.ApplicationInfo.getNativeOrientation() === Qt.PortraitOrientation) {
+            // lock screen orientation: (as changing orientation would reset the level...)
+            GCompris.ApplicationInfo.setRequestedOrientation(14);
+            if (GCompris.ApplicationInfo.getNativeOrientation() === Qt.PortraitOrientation &&
+                items.activityBackground.width > items.activityBackground.height) {
                 /*
-                 * Adjust tilting if native orientation != landscape.
+                 * Adjust tilting if native orientation != landscape but orientation is landscape.
                  *
                  * Note: As of Qt 5.4.1 QTiltSensor as well as QRotationSensor
                  * report on Android
@@ -100,7 +101,7 @@ function start(items_) {
         }
         else {
             if(items.levelSet === "user") {
-                Core.showMessageDialog(items.background,
+                Core.showMessageDialog(items.activityBackground,
                                         // The argument represents the file path name to be loaded.
                                        qsTr("The file '%1' is missing!<br>Falling back to builtin levels.").arg(items.filePath) + "<br>" + createLevelsMsg,
                                        "", null,
