@@ -10,7 +10,7 @@
 
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 Qt.include("../balancebox_common.js")
