@@ -21,7 +21,7 @@ var currentDataSet
 
 function start(items_, dataset_) {
     items = items_
-    dataset = dataset_.get()
+    dataset = dataset_
     numberOfLevel = dataset.length * 2
     items.currentLevel = Core.getInitialLevel(numberOfLevel)
     initLevel()
@@ -116,7 +116,7 @@ function goodAnswer() {
     items.buttonsBlocked = true
     items.score.currentSubLevel++
     items.score.playWinAnimation()
-    items.audioEffects.play("qrc:/gcompris/src/core/resource/sounds/completetask.wav");
+    items.goodAnswerSound.play()
 }
 
 function nextQuestion() {
