@@ -9,7 +9,7 @@
  *    "tRs" = triangle, red and small
  */
 .pragma library
-.import GCompris 1.0 as GCompris // for ApplicationInfo
+.import core 1.0 as GCompris // for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 const svgUrl = "qrc:/gcompris/src/activities/frieze/resource/svg/"
@@ -232,7 +232,7 @@ function checkResult() {
 function initLevel() {
     items.buttonsBlocked = false;
     numberOfLevel = items.levels.length;
-    items.instruction.text = items.levels[items.currentLevel].title;
+    items.instructionItem.text = items.levels[items.currentLevel].title;
     items.subLevelCount = items.levels[items.currentLevel].subLevels.length;
     if (items.levels[items.currentLevel].shuffle)
         Core.shuffle(items.levels[items.currentLevel].subLevels);
