@@ -11,7 +11,7 @@
 
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
 
@@ -48,7 +48,7 @@ function start(items_) {
 
     var data = Lang.loadDataset(items.parser, resourceUrl, locale);
     dataset = data["dataset"];
-    items.background.englishFallback = data["englishFallback"];
+    items.activityBackground.englishFallback = data["englishFallback"];
     lessons = Lang.getAllLessons(dataset);
     numberOfLevel = lessons.length;
     items.currentLevel = Core.getInitialLevel(numberOfLevel);
@@ -111,8 +111,8 @@ function initLevel() {
 }
 
 function processKeyPress(text) {
-    if(items.ok.visible) {
-        items.ok.clicked();
+    if(items.okButton.visible) {
+        items.okButton.clicked();
         return;
     }
     if(items.remainingLife === 0 || items.goodIcon.visible) {
@@ -160,7 +160,7 @@ function processKeyPress(text) {
 
     // If no more '_' in the word to find, we have found all letters, show bonus
     if(items.hidden.text.indexOf("_") === -1) {
-        items.maskThreshold = 0;
+        items.maskEffect.maskThresholdMin = 0;
         items.playWord();
         items.hidden.text = items.goodWord.translatedTxt;
         items.goodIcon.visible = true;
@@ -188,7 +188,7 @@ function initSubLevel() {
     else
         items.score.visible = false;
     items.goodWordIndex = subLevelsLeft.pop();
-    items.ok.visible = false;
+    items.okButton.visible = false;
     items.goodIcon.visible = false;
     items.goodWord = wordList[items.goodWordIndex];
     items.wordImage.changeSource(items.goodWord.image);
