@@ -30,13 +30,12 @@
 
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var levels;
 var numberOfLevel;
 var items = null;
-var baseUrl = "qrc:/gcompris/src/activities/land_safe/resource";
 var startingAltitudeReal = 100.0;
 var startingOffsetPx = 10;  // y-value for setting rocket initially
 var maxLandingVelocity = 10;
@@ -91,7 +90,7 @@ function initLevel() {
     items.explosion.hide();
     items.rocket.show();
     // place rocket randomly:
-    var max = items.background.width - items.accelerometer.width - items.landing.width - items.rocket.width;
+    var max = items.activityBackground.width - items.accelerometer.width - items.landing.width - items.rocket.width;
     var min = 20;
     items.rocket.x = Math.random() * (max- min) + min;
     items.rocket.y = startingOffsetPx;
@@ -103,7 +102,7 @@ function initLevel() {
     // for landing random placement shall not intersect with bar -- or osd
     // controls on mobile:
     min = items.onScreenControls ? items.leftRightControl.width : items.bar.width;
-    max = items.onScreenControls ? items.background.width - items.upDownControl.width - items.landing.width : max;
+    max = items.onScreenControls ? items.activityBackground.width - items.upDownControl.width - items.landing.width : max;
     items.landing.anchors.leftMargin = Math.random() * (max- min) + min;
     items.landing.overlayColor = "-g";
     items.leftEngine.reset();
@@ -119,12 +118,12 @@ function initLevel() {
 
     if (levels[items.currentLevel].intro !== undefined) {
         items.ok.visible = false;
-        items.intro.intro = [levels[items.currentLevel].intro];
-        items.intro.index = 0;
+        items.introMessage.intro.clear()
+        items.introMessage.intro.append({"text": levels[items.currentLevel].intro})
+        items.introMessage.index = 0;
     } else {
         // go
-        items.intro.intro = [];
-        items.intro.index = -1;
+        items.introMessage.index = -1;
         items.ok.visible = true;
     }
     lastLevel = items.currentLevel;
@@ -132,14 +131,14 @@ function initLevel() {
 
 function pxAltitudeToY(alt)
 {
-    var y = items.background.height - items.ground.height + items.ground.surfaceOffset
+    var y = items.activityBackground.height - items.ground.height + items.ground.surfaceOffset
             - items.rocket.height - 1 - alt;
     return y;
 }
 
 function pxYToAltitude(y)
 {
-    var altPx = items.background.height - items.ground.height + items.ground.surfaceOffset
+    var altPx = items.activityBackground.height - items.ground.height + items.ground.surfaceOffset
             - y - items.rocket.height
             - 1;  // landing is 1 pixel above ground surface
     return altPx;
