@@ -14,7 +14,7 @@
 
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris //for ApplicationInfo
+.import core 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/core/core.js" as Core
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
 
@@ -48,8 +48,8 @@ function loadDataset() {
     var resourceUrl = "qrc:/gcompris/src/activities/lang/resource/";
     var data = Lang.loadDataset(items.parser, resourceUrl, locale);
     dataset = data["dataset"];
-    items.background.englishFallback = data["englishFallback"];
-    if(!items.background.englishFallback)
+    items.activityBackground.englishFallback = data["englishFallback"];
+    if(!items.activityBackground.englishFallback)
         Core.checkForVoices(items.activityPage);
 }
 
@@ -112,12 +112,19 @@ function initLevel() {
     if (GCompris.ApplicationSettings.isAudioVoicesEnabled &&
             GCompris.DownloadManager.haveLocalResource(
                 GCompris.DownloadManager.getVoicesResourceForLocale(locale))) {
-        items.audioVoices.silence(500)
-        playLetter(currentLetter)
+        appendVoice();
     }
     items.buttonsBlocked = false;
 }
 
+function appendVoice() {
+    if(GCompris.DownloadManager.areVoicesRegistered(items.locale)) {
+        playLetter(currentLetter);
+    } else {
+        items.voiceTimer.start();
+    }
+}
+
 function calculateFrequency() {
     var freq = [];
     for(var i = 0; i < words.length; i++) {
