@@ -11,6 +11,7 @@
  */
 .pragma library
 .import QtQuick 2.12 as Quick
+.import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var url = "qrc:/gcompris/src/activities/memory/resource/"
@@ -80,9 +81,10 @@ function initLevel() {
     for(var ix = 0;  ix < nbOfPair; ++ix) {
         // select a random item
         for(var j = 0; j < 2; ++j) {
+            var sound = (sounds && sounds[shuffleIds[ix]][j]) ? GCompris.ApplicationInfo.getAudioFilePath(sounds[shuffleIds[ix]][j]) : ""
             cardList.push( {
                 image: images ? images[shuffleIds[ix]][j] : "",
-                sound: sounds ? sounds[shuffleIds[ix]][j] : "",
+                sound: sound,
                 text: texts ? texts[shuffleIds[ix]][j] : "",
                 repeaterModel: repeaterModels ? repeaterModels[shuffleIds[ix]][j] : "",
                 matchCode: ix,
@@ -114,9 +116,9 @@ function initLevel() {
 // Return a pair of cards that have already been shown
 function getShownPair() {
     for(var i = 0;  i < nbOfPair * 2; ++i) {
-        var cardItem1 = items.grid.getItemAtIndex(i)
+        var cardItem1 = items.cardGrid.itemAtIndex(i)
         for(var j = 0;  j < nbOfPair * 2; ++j) {
-            var cardItem2 = items.grid.getItemAtIndex(j)
+            var cardItem2 = items.cardGrid.itemAtIndex(j)
             if(i != j &&
                 !cardItem1.isFound &&
                 cardItem1.isShown &&
@@ -154,9 +156,9 @@ function chooseCard() {
     // If no pairs shown select a random card
     var listCardNonReturned = []
     for(var i = 0;  i < cardList.length; ++i) {
-        if (items.grid.getItemAtIndex(i).isFound == false &&
-            items.grid.getItemAtIndex(i).isBack)
-            listCardNonReturned.push(items.grid.getItemAtIndex(i))
+        if (items.cardGrid.itemAtIndex(i).isFound == false &&
+            items.cardGrid.itemAtIndex(i).isBack)
+            listCardNonReturned.push(items.cardGrid.itemAtIndex(i))
     }
 
     //select randomly a card in it
