@@ -11,7 +11,7 @@
 .pragma library
 .import QtQuick 2.12 as Quick
 .import "qrc:/gcompris/src/core/core.js" as Core
-.import GCompris 1.0 as GCompris //for ApplicationInfo
+.import core 1.0 as GCompris //for ApplicationInfo
 .import "qrc:/gcompris/src/activities/lang/lang_api.js" as Lang
 
 var url = "qrc:/gcompris/src/activities/missing-letter/resource/"
@@ -62,12 +62,12 @@ function start() {
     // If still dataset is empty then fallback to english
     if(!dataset) {
         // English fallback
-        items.background.englishFallback = true
+        items.activityBackground.englishFallback = true
         dataset = Lang.load(items.parser, langUrl,
                             GCompris.ApplicationSettings.useExternalWordset() ? "words.json" : "words_sample.json",
                             "content-en.json")
     } else {
-        items.background.englishFallback = false
+        items.activityBackground.englishFallback = false
     }
 
     lessons = Lang.getAllLessons(dataset)
