@@ -10,7 +10,7 @@
  */
 .pragma library
 .import "qrc:/gcompris/src/core/core.js" as Core
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "moneyConstants.js" as MoneyConstants
 
 var url = "qrc:/gcompris/src/activities/money/resource/"
@@ -123,6 +123,12 @@ function initLevel() {
             }
             priceTotal += cents
             price += cents
+            // For the last item, make sure we are not above the maximum
+            if(priceTotal > data.maxPrice && i == data.numberOfItem - 1) {
+                var diff = priceTotal - data.maxPrice
+                priceTotal = data.maxPrice
+                price -= diff
+            }
         }
 
         var priceText = Core.convertNumberToLocaleCurrencyString(Number(price), locale)
