@@ -24,28 +24,6 @@ var numberOfSecondPieces
 var numberOfPieces
 var numberOfDragPoints
 var depthMax
-var tutorialInstructions = [
-            {
-                "instruction": qsTr("You and Tux start with 9 pieces each, and take turns to place your pieces on the empty spots of the board (by clicking on the spots)."),
-                "instructionImage" : "qrc:/gcompris/src/activities/nine_men_morris/resource/tutorial1.svg"
-            },
-            {
-                "instruction": qsTr("If you form a mill (line of 3 pieces), then select one of Tux's pieces to remove it. Pieces of formed mill can not be removed unless no other pieces are left on the board."),
-                "instructionImage": "qrc:/gcompris/src/activities/nine_men_morris/resource/tutorial2.svg"
-            },
-            {
-                "instruction": qsTr("After all the pieces are placed, you and Tux will take turns to move them. Click on one of your pieces, and then on an adjacent empty spot to move it there. Green color spots indicates where you can move."),
-                "instructionImage": "qrc:/gcompris/src/activities/nine_men_morris/resource/tutorial3.svg"
-            },
-            {
-                "instruction":  qsTr("If you are left with 3 pieces, they gain the ability to 'fly' and can be moved to any vacant spot on the board."),
-                "instructionImage": "qrc:/gcompris/src/activities/nine_men_morris/resource/tutorial4.svg"
-            },
-            {
-                "instruction": qsTr("If you immobilize the computer or leave it with less than 3 pieces, then you win the game."),
-                "instructionImage": "qrc:/gcompris/src/activities/nine_men_morris/resource/tutorial5.svg"
-            }
-        ]
 
 function start(items_, twoPlayer_) {
     items = items_
@@ -259,7 +237,7 @@ function initLevel() {
     numberOfSecondPieces = 0
     items.firstPieceNumberCount = numberOfPieces
     items.secondPieceNumberCount = numberOfPieces
-    items.instructionTxt = qsTr("Place a piece")
+    items.instructionTxt.text = qsTr("Place a piece")
     depthMax = 2
 
     // Clear first and second player pieces, and initialize dragPoints
@@ -385,7 +363,7 @@ function secondPhase() {
             items.dragPoints.itemAt(i).state = "EMPTY"
     }
 
-    items.instructionTxt = qsTr("Move a piece")
+    items.instructionTxt.text = qsTr("Move a piece")
 }
 
 function pieceSelected(pieceIndex) {
@@ -937,7 +915,7 @@ function updateRemovablePiece() {
                     otherRepeater.itemAt(i).canBeRemoved = true
             }
         }
-        items.instructionTxt = qsTr("Remove a piece")
+        items.instructionTxt.text = qsTr("Remove a piece")
     }
     else if(items.currentLevel < 4) {
         if(items.firstPhase)
@@ -1105,7 +1083,7 @@ function removePiece(index) {
     else
         numberOfSecondPieces --
     if(items.firstPhase) {
-        items.instructionTxt = qsTr("Place a piece")
+        items.instructionTxt.text = qsTr("Place a piece")
         continueGame()
     }
     else
@@ -1140,10 +1118,10 @@ function checkGameWon() {
         items.gameDone = true
         items.player1score.win();
         items.player2score.endTurn();
-        items.instructionTxt = qsTr("Congratulations")
+        items.instructionTxt.text = qsTr("Congratulations")
         items.bonus.good("flower")
         if(twoPlayer) {
-            items.instructionTxt = qsTr("Congratulations Player 1")
+            items.instructionTxt.text = qsTr("Congratulations Player 1")
         }
     }
     else if(((numberOfFirstPieces < 3 && !items.playSecond) || (numberOfSecondPieces < 3 && items.playSecond)) ||
@@ -1154,16 +1132,16 @@ function checkGameWon() {
         items.player1score.endTurn();
         if(twoPlayer) {
             items.bonus.good("flower")
-            items.instructionTxt = qsTr("Congratulations Player 2")
+            items.instructionTxt.text = qsTr("Congratulations Player 2")
         }
         else {
-            items.instructionTxt = qsTr("Try again")
+            items.instructionTxt.text = qsTr("Try again")
             items.bonus.bad("tux")
         }
     }
     else {
         // Continue the game
-        items.instructionTxt = qsTr("Move a piece")
+        items.instructionTxt.text = qsTr("Move a piece")
         continueGame()
     }
 }
