@@ -11,7 +11,7 @@
  */
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "../../core/core.js" as Core
 
 var numberOfLevel = 0
@@ -186,3 +186,21 @@ function checkOrder() {
     else
         items.bonus.bad("lion")
 }
+
+function moveFromTargetList(from_, to_, n_) {
+    items.targetListModel.move(from_, to_, n_)
+}
+
+function dropElement(element_, fromListName_) {
+    var modelObj = {
+        "elementValue" : element_.elementValue,
+        "borderColor" : "#808080"
+    }
+    if(fromListName_ === "target") {
+        items.targetListModel.append(modelObj)
+        items.originListModel.remove(element_.index)
+    } else { // "origin" case
+        items.originListModel.append(modelObj)
+        items.targetListModel.remove(element_.index)
+    }
+}
