@@ -104,7 +104,7 @@ function processMove(player, ind) {
 
     if(!isValidMove(pit)) {
         items.invalidMoveAnimation.start(pit)
-        items.instructionArea.start(qsTr("Invalid Move!"))
+        items.instructionPanel.start(qsTr("Invalid Move!"))
         return
     }
 
@@ -222,7 +222,7 @@ function nextClockwise(lastPos) {
 }
 
 function getGlobalPos(component) {
-    if(!component || component.id === "background")
+    if(!component || component.id === "activityBackground")
         return [0, 0]
 
     var pos = getGlobalPos(component.parent)
