@@ -1,13 +1,18 @@
 /* GCompris - share.js
  *
  * SPDX-FileCopyrightText: 2016 Stefan Toncu <stefan.toncu29@gmail.com>
+ * SPDX-FileCopyrightText: 2025 Timothée Giet <animtim@gmail.com>
+ *
+ * Authors:
+ *   Stefan Toncu <stefan.toncu29@gmail.com> (initial version)
+ *   Timothée Giet <animtim@gmail.com> (refactoring)
  *
  *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 
 .pragma library
 .import QtQuick 2.12 as Quick
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 .import "qrc:/gcompris/src/core/core.js" as Core
 
 var numberOfLevel
@@ -48,17 +53,17 @@ function setUp() {
         items.instruction.text = subLevelData.instruction
         items.nbSubLevel = levelData[items.currentLevel].length
 
-        items.background.currentCandies = items.totalGirls * subLevelData.placedInGirls +
+        items.activityBackground.currentCandies = items.totalGirls * subLevelData.placedInGirls +
                 items.totalBoys * subLevelData.placedInBoys
 
-        items.background.placedInGirls = subLevelData.placedInGirls
-        items.background.placedInBoys = subLevelData.placedInBoys
+        items.activityBackground.placedInGirls = subLevelData.placedInGirls
+        items.activityBackground.placedInBoys = subLevelData.placedInBoys
 
-        items.background.rest = items.totalCandies -
+        items.activityBackground.rest = items.totalCandies -
                 Math.floor(items.totalCandies / items.totalChildren) * (items.totalBoys+items.totalGirls)
         items.basketWidget.element.opacity = (subLevelData.forceShowBasket === true ||
-                                              items.background.rest !== 0) ? 1 : 0
-        items.background.wrongMove.visible = false
+                                              items.activityBackground.rest !== 0) ? 1 : 0
+        items.activityBackground.wrongMove.visible = false
     }
     else {
         // create random (guided) levels
@@ -70,28 +75,40 @@ function setUp() {
         items.totalBoys = Math.floor(Math.random() * maxBoys) + 1
         items.totalGirls = Math.floor(Math.random() * maxGirls) + 1
         var sum = items.totalBoys + items.totalGirls
-        // use sum * 6 as top margin (max 6 candies per rectangle)
-        items.totalCandies = Math.floor(Math.random() * (5 * sum + 1)) + sum
+        // use sum * 6 as top margin (max 6 candies per rectangle, and minimum 1 per child)
+        items.totalCandies = Math.floor(Math.random() * 6 * sum) + sum
         items.nbSubLevel = levelData[items.currentLevel].length
         // stay within the max margin
         if (items.totalCandies > maxCandies)
             items.totalCandies = maxCandies
 
+        items.activityBackground.placedInGirls = 0
+        items.activityBackground.placedInBoys = 0
+        items.activityBackground.currentCandies = 0
         // depending on the levels configuration, add candies from start in a child rectangle
-        if (subLevelData.alreadyPlaced === false) {
-            items.background.placedInGirls = 0
-            items.background.placedInBoys = 0
-            items.background.currentCandies = 0
-        }
-        else {
-            items.background.currentCandies = items.totalCandies * 2
-            // Place randomly between 0 and 3 candies for each child
-            while (items.background.currentCandies > items.totalCandies / 3) {
-                items.background.placedInGirls = Math.floor(Math.random() * 3)
-                items.background.placedInBoys = Math.floor(Math.random() * 3)
-                items.background.currentCandies = items.totalGirls * items.background.placedInGirls
-                        + items.totalBoys * items.background.placedInBoys
+        if (subLevelData.alreadyPlaced) {
+            items.activityBackground.placedInGirls = 0
+            items.activityBackground.placedInBoys = 0
+            items.activityBackground.currentCandies = 0
+            // Max number of already placed candies depending on number of candies per children, but -1 do not place them all
+            var maxPlacedCandies = Math.floor(items.totalCandies / sum) - 1;
+            // Maximum 3 placed candies per child
+            var placedInSum = maxPlacedCandies / sum;
+            if(placedInSum < 0) {
+                placedInSum = 0;
+            } else if(placedInSum > 3) {
+                placedInSum = 3;
             }
+            for (var i = 0; i < placedInSum; i++) {
+                var inBoys = Math.round(Math.random())
+                if(inBoys == 1) {
+                    items.activityBackground.placedInBoys += 1;
+                } else {
+                    items.activityBackground.placedInGirls += 1;
+                }
+            }
+            items.activityBackground.currentCandies = items.totalGirls * items.activityBackground.placedInGirls
+                + items.totalBoys * items.activityBackground.placedInBoys
         }
         //~ singular "Place %n boy "
         //~ plural "Place %n boys "
@@ -103,15 +120,15 @@ function setUp() {
 
         //~ singular Then split %n candy equally between them.
         //~ plural Then split %n candies equally between them.
-        items.instruction.text += qsTr("Then split %n pieces of candy equally between them.", "Third part of Place %n boy(s) and %n girl(s) in the center. Then split %n pieces of candy equally between them.", items.totalCandies - items.background.currentCandies);
+        items.instruction.text += qsTr("Then split %n pieces of candy equally between them.", "Third part of Place %n boy(s) and %n girl(s) in the center. Then split %n pieces of candy equally between them.", items.totalCandies - items.activityBackground.currentCandies);
 
 
-        items.background.rest = items.totalCandies -
+        items.activityBackground.rest = items.totalCandies -
                 Math.floor(items.totalCandies / items.totalChildren) * (items.totalBoys+items.totalGirls)
 
         items.basketWidget.element.opacity = 1
 
-        items.background.wrongMove.visible = false;
+        items.activityBackground.wrongMove.visible = false;
 
         saveVariables()
     }
@@ -119,12 +136,12 @@ function setUp() {
 }
 
 function resetBoard() {
-    items.background.currentGirls = 0
-    items.background.currentBoys = 0
-    items.background.resetCandy()
+    items.activityBackground.currentGirls = 0
+    items.activityBackground.currentBoys = 0
+    items.activityBackground.resetCandy()
 
     items.acceptCandy = false
-    items.instruction.opacity = 1
+    items.instructionPanel.opacity = 1
     items.listModel.clear()
 
     items.girlWidget.current = 0
@@ -137,7 +154,7 @@ function resetBoard() {
 
     items.candyWidget.canDrag = true
     items.candyWidget.element.opacity = 1
-    if (items.totalCandies - items.background.currentCandies == 0)
+    if (items.totalCandies - items.activityBackground.currentCandies == 0)
         items.candyWidget.element.opacity = 0.6
 
     items.basketWidget.canDrag = true
@@ -148,18 +165,18 @@ function saveVariables() {
     savedTotalBoys = items.totalBoys
     savedTotalGirls = items.totalGirls
     savedTotalCandies = items.totalCandies
-    savedPlacedInGirls = items.background.placedInGirls
-    savedPlacedInBoys = items.background.placedInBoys
-    savedCurrentCandies = items.background.currentCandies
+    savedPlacedInGirls = items.activityBackground.placedInGirls
+    savedPlacedInBoys = items.activityBackground.placedInBoys
+    savedCurrentCandies = items.activityBackground.currentCandies
 }
 
 function loadVariables() {
     items.totalBoys = savedTotalBoys
     items.totalGirls = savedTotalGirls
     items.totalCandies = savedTotalCandies
-    items.background.placedInGirls = savedPlacedInGirls
-    items.background.placedInBoys = savedPlacedInBoys
-    items.background.currentCandies = savedCurrentCandies
+    items.activityBackground.placedInGirls = savedPlacedInGirls
+    items.activityBackground.placedInBoys = savedPlacedInBoys
+    items.activityBackground.currentCandies = savedCurrentCandies
 }
 
 function reloadRandom() {
@@ -170,7 +187,7 @@ function reloadRandom() {
         loadVariables()
         resetBoard()
 
-        items.background.rest = items.totalCandies -
+        items.activityBackground.rest = items.totalCandies -
                 Math.floor(items.totalCandies / items.totalChildren) * (items.totalBoys+items.totalGirls)
         items.basketWidget.element.opacity = 1
     }
