@@ -20,6 +20,8 @@
 #include <QUrl>
 #include <QQmlEngine>
 #include <QJSEngine>
+#include <QtQml/qqmlregistration.h>
+#include <config.h>
 
 namespace GCompris {
     Q_NAMESPACE
@@ -81,7 +83,10 @@ namespace GCompris {
 class DownloadManager : public QObject
 {
     Q_OBJECT
-
+#ifndef WITH_RCC
+    QML_ELEMENT
+    QML_SINGLETON
+#endif
     friend class DownloadManagerTest;
 
 private:
@@ -237,8 +242,8 @@ public:
     /**
      * Registers DownloadManager singleton in the QML engine.
      */
-    static QObject *downloadManagerProvider(QQmlEngine *engine,
-                                            QJSEngine *scriptEngine);
+    static DownloadManager *create(QQmlEngine *engine,
+                                   QJSEngine *scriptEngine);
     static DownloadManager *getInstance();
 
     /**
@@ -280,14 +285,14 @@ public:
      *
      * @param data Relative resource path (file or directory).
      *
-     * @sa areVoicesRegistered
+     * @sa isDataRegistered
      */
     Q_INVOKABLE bool isDataRegistered(const QString &data) const;
 
     /**
      * Whether voices for the locale passed in parameter are registered.
      *
-     * @sa isDataRegistered
+     * @sa areVoicesRegistered
      */
     Q_INVOKABLE bool areVoicesRegistered(const QString &locale) const;
 
