@@ -30,8 +30,14 @@ QString File::sanitizeUrl(const QString &url)
     QString target(url);
 
     // make sure we strip off invalid URL schemes:
-    if (target.startsWith(QLatin1String("file://")))
+    // for windows, where path starts with C:/...
+    if (target.startsWith(QLatin1String("file://")) && target.indexOf(":", 9) == 9) {
+        target.remove(0, 8);
+    }
+    // for linux, where path starts with /...
+    else if (target.startsWith(QLatin1String("file://"))) {
         target.remove(0, 7);
+    }
     else if (target.startsWith(QLatin1String("qrc:/")))
         target.remove(0, 3);
 
@@ -65,11 +71,7 @@ QString File::read(const QString &name)
         QTextStream t(&file);
         /* Force utf-8 : for some languages, it seems to be loaded in other
           encoding even if the file is in utf-8 */
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         t.setEncoding(QStringConverter::Utf8);
-#else
-        t.setCodec("UTF-8");
-#endif
         do {
             line = t.readLine();
             fileContent += line;
@@ -102,11 +104,7 @@ bool File::write(const QString &data, const QString &name)
 
     QTextStream out(&file);
     /* Force utf-8 : needed at least for Windows */
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     out.setEncoding(QStringConverter::Utf8);
-#else
-    out.setCodec("UTF-8");
-#endif
     out << data;
 
     file.close();
@@ -132,11 +130,7 @@ bool File::append(const QString &data, const QString &name)
 
     QTextStream out(&file);
     /* Force utf-8 : needed at least for Windows */
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     out.setEncoding(QStringConverter::Utf8);
-#else
-    out.setCodec("UTF-8");
-#endif
 
     out << data;
 
@@ -145,6 +139,26 @@ bool File::append(const QString &data, const QString &name)
     return true;
 }
 
+bool File::copy(const QString &sourceFile, const QString &name)
+{
+    if (!name.isEmpty())
+        setName(name);
+
+    if (m_name.isEmpty()) {
+        Q_EMIT error("source is empty");
+        return false;
+    }
+
+    if (QFile::exists(m_name)) {
+        QFile::remove(m_name);
+    }
+
+    QString sanitizedSourceFile = sanitizeUrl(sourceFile);
+    QFile::copy(sanitizedSourceFile, m_name);
+
+    return true;
+}
+
 bool File::exists(const QString &path)
 {
     return QFile::exists(sanitizeUrl(path));
