@@ -18,7 +18,7 @@
  */
 .pragma library
 .import QtQml 2.12 as Qml
-.import GCompris 1.0 as GCompris
+.import core 1.0 as GCompris
 
 /**
  * Shuffle the array @p o and returns it.
